/*
 * CreateMaster.cpp
 *
 * (C) 2001 MagnumMan-iCoP (James E. King, III)
 */

#include "StdAfx.h"

#include "ShipList.h"

//
// CreateMaster
//
// Reads the ship list from the specification files
// Since the list is made entirely from classes and std:: items,
// it will self destruct when it pops off the stack.
//
// Params:	meta	If true, the MetaAssets are read, otherwise the regular
//					assets are read.
//
// Returns:	bool	Indicating success or failure
//

bool ShipList::CreateMaster(eGame game, bool meta)
{
	std::string	shiplistFN;
	std::string	ftrlistFN;
	std::string	specsDir;
	//
	// Find the ship and fighter list files
	//

	if (!FindSpecsDirectory(game, meta, specsDir))
		return false;

	shiplistFN = specsDir;
	shiplistFN += "shiplist.txt";

	ftrlistFN = specsDir;
	ftrlistFN += "ftrlist.txt";

	return CreateMaster(shiplistFN, ftrlistFN);
}

bool ShipList::CreateMaster(const char *shiplist, const char *ftrlist)
{
	return CreateMaster(std::string(shiplist), std::string(ftrlist));
}

bool ShipList::CreateMaster(std::string shiplistFN, std::string ftrlistFN)
{	
	FILE *		shipFP;
	FILE *		ftrFP;
	bool		skip;
	int			line = 1;

	shipFP = fopen(shiplistFN.c_str(), "r");
	if (!shipFP)
		return false;

	ftrFP = fopen(ftrlistFN.c_str(), "r");
	if (!ftrFP)
	{
		fclose(shipFP);
		return false;
	}

	//
	// Read and parse the ship lists, one line at a time, skipping the first 2 lines.
	//

	// Fighter list comes first so we can populate ships properly.
	skip = true;
	for (;;)
	{
		char inputBuf[1024];
		if (!fgets(inputBuf, 1024, ftrFP))
			break;		// assume EOF
	
		if (skip)		// Find first entry
		{
			if (!strncmp(inputBuf, "Federation", 10))
				skip = false;
			else
				continue;
		}

		inputBuf[strlen(inputBuf) - 1] = 0x00;		/* trip EOL-CR */

		Ship	aShip;
		if (!decodeFighter(inputBuf, aShip))
			break;

	//	push_back(aShip);
		fighters_and_pfs.push_back(aShip);
	}

	//
	// First pass, read the PFs
	// That way we can properly initialize the ships.
	//
	
	line = 1;
	skip = true;
	for (;;)
	{
		char	inputBuf[4096];
		if (!fgets(inputBuf, 4096, shipFP))
			break;		// assume EOF

		if (skip)		// Find first entry
		{
			if (!strncmp(inputBuf, "Federation", 10))
				skip = false;
			else
				continue;
		}

		if (!strncmp(inputBuf, "\tThis is the last line.  End of File.", 37))
			break;

		Ship	aShip;
		if (!decodeShip(inputBuf, aShip, true))
			continue;

		push_back(aShip);
		if (aShip.shipClass == kClassPseudoFighter)
			fighters_and_pfs.push_back(aShip);
	}

	fseek(shipFP, 0, SEEK_SET);
	line = 1;
	skip = true;
	for (;;)
	{
		char	inputBuf[4096];
		if (!fgets(inputBuf, 4096, shipFP))
			break;		// assume EOF

		if (skip)		// Find first entry
		{
			if (!strncmp(inputBuf, "Federation", 10))
				skip = false;
			else
				continue;
		}

		if (!strncmp(inputBuf, "\tThis is the last line.  End of File.", 37))
			break;

		Ship	aShip;
		if (!decodeShip(inputBuf, aShip))
			continue;

		push_back(aShip);
		if (aShip.shipClass == kClassPseudoFighter)
			fighters_and_pfs.push_back(aShip);
	}

	fclose(ftrFP);
	fclose(shipFP);
	return true;
}

